<?php

namespace LakeDrops\Component\Dotenv;

use Symfony\Component\Dotenv\Dotenv as SymfonyDotenv;

/**
 * Manages .env files.
 */
final class Dotenv {

  /** @var string */
  private $name;

  /** @var \Composer\IO\IOInterface */
  private $io;

  /** @var \Symfony\Component\Dotenv\Dotenv */
  private $dotenv;

  /**
   * Dotenv constructor.
   *
   * @param string $name
   * @param \Composer\IO\IOInterface $io
   */
  public function __construct($name, $io) {
    $this->name = strtoupper($name);
    $this->io = $io;
    $this->dotenv = new SymfonyDotenv();
    $this->load();
  }

  /**
   * @param string $key
   * @param string $prompt
   *
   * @return string
   */
  public function receive($key, $prompt) {
    $key = $this->name . '_' . strtoupper($key);
    $value = getenv($key);
    if (empty($value)) {
      if ($this->io->isInteractive()) {
        $value = $this->io->ask($prompt . ': ');
        $this->putenv($key, $value);
      }
    }
    return $value;
  }

  private function load() {
    try {
      $this->dotenv->load('.env');
    }
    catch (\Exception $ex) {
      // Ignore
    }
  }

  private function putenv($key, $value) {
    $env = file_exists('.env') ? file_get_contents('.env') : '';
    $env .= PHP_EOL . $key . '=' . $value . PHP_EOL;
    file_put_contents('.env', $env);
    $this->load();
  }

}
